This folder contains examples of the use of the pygaia modules.

The examples for the older versions of pygaia can be found at
[https://github.com/agabrown/pygaia-v1](https://github.com/agabrown/pygaia-v1)